==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "存储空间不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "Unable to set upload directory." : "无法设置上传文件夹。",
    "Invalid Token" : "无效密匙",
    "No file was uploaded. Unknown error" : "没有文件被上传。未知错误",
    "There is no error, the file uploaded with success" : "文件上传成功，没有错误发生",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上传文件大小已超过php.ini中upload_max_filesize所规定的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
    "The uploaded file was only partially uploaded" : "已上传文件只上传了部分（不完整）",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时目录",
    "Failed to write to disk" : "写入磁盘失败",
    "Not enough storage available" : "没有足够的存储空间",
    "The target folder has been moved or deleted." : "目标文件夹已经被移动或删除。",
    "Upload failed. Could not find uploaded file" : "上传失败。未发现上传的文件",
    "Upload failed. Could not get file info." : "上传失败。无法获取文件信息。",
    "Invalid directory." : "无效文件夹。",
    "Files" : "文件",
    "All files" : "全部文件",
    "Favorites" : "收藏",
    "Home" : "家庭",
    "Close" : "关闭",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
    "Total file size {size1} exceeds upload limit {size2}" : "总文件大小 {size1} 超过上传限制 {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
    "Could not get result from server." : "不能从服务器得到结果",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中。现在离开此页会导致上传动作被取消。",
    "Actions" : "动作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Delete" : "删除",
    "Disconnect storage" : "断开储存连接",
    "Unshare" : "取消共享",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "不能重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "在文件夹 \"{dir}\" 中已经存在 \"{targetName}\" 。请换一个名字试下。",
    "Could not rename \"{fileName}\"" : "不能重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "不能创建文件夹 \"{dir}\" ，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "No entries in this folder match '{filter}'" : "此文件夹中无项目匹配“{filter}”",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 文件夹"],
    "_%n file_::_%n files_" : ["%n个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "You don’t have permission to upload or create files here" : "您没有权限来上传湖州哦和创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配“{filter}”"],
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Folder" : "文件夹",
    "New folder" : "增加文件夹",
    "{newname} already exists" : "{newname} 已经存在",
    "Upload" : "上传",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "A new file or folder has been <strong>created</strong>" : "一个新的文件或文件夹已被<strong>创建</strong>",
    "A file or folder has been <strong>changed</strong>" : "一个文件或文件夹已被<strong>修改</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "针对<strong>已收藏文件</strong>的新建和修改发送有限的通知 <em>(仅流)</em>",
    "A file or folder has been <strong>deleted</strong>" : "一个文件或文件夹已被<strong>删除</strong>",
    "A file or folder has been <strong>restored</strong>" : "一个文件或文件夹已经被 <strong>恢复</strong>",
    "You created %1$s" : "您创建了%1$s",
    "%2$s created %1$s" : "%2$s 创建了 %1$s",
    "%1$s was created in a public folder" : "%1$s 被创建在公开文件夹中",
    "You changed %1$s" : "您修改了%1$s",
    "%2$s changed %1$s" : "%2$s 修改了 %1$s",
    "You deleted %1$s" : "您删除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 删除了 %1$s",
    "You restored %1$s" : "你恢复了 %1$s",
    "%2$s restored %1$s" : "%2$s 恢复了 %1$s",
    "Changed by %2$s" : "被 %2$s 更改",
    "Deleted by %2$s" : "被 %2$s 删除",
    "Restored by %2$s" : "被 %2$s 恢复",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有从这里进行编辑的权限",
    "Settings" : "设置",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\">通过 WebDAV 访问您的文件</a>",
    "Cancel upload" : "取消上传",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传一些内容或者与设备同步!",
    "No entries found in this folder" : "此文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您正尝试上传的文件超过了此服务器可以上传的最大容量限制",
    "No favorites" : "无收藏",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt",
    "Changed by %2$s" : "被 %2$s 更改",
    "Deleted by %2$s" : "被 %2$s 删除",
    "Restored by %2$s" : "被 %2$s 恢复",
    "You changed %1$s" : "您修改了%1$s",
    "You created %1$s" : "您创建了%1$s",
    "You deleted %1$s" : "您删除了 %1$s",
    "You restored %1$s" : "你恢复了 %1$s"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "存储空间不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "Unable to set upload directory." : "无法设置上传文件夹。",
    "Invalid Token" : "无效密匙",
    "No file was uploaded. Unknown error" : "没有文件被上传。未知错误",
    "There is no error, the file uploaded with success" : "文件上传成功，没有错误发生",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上传文件大小已超过php.ini中upload_max_filesize所规定的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
    "The uploaded file was only partially uploaded" : "已上传文件只上传了部分（不完整）",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时目录",
    "Failed to write to disk" : "写入磁盘失败",
    "Not enough storage available" : "没有足够的存储空间",
    "The target folder has been moved or deleted." : "目标文件夹已经被移动或删除。",
    "Upload failed. Could not find uploaded file" : "上传失败。未发现上传的文件",
    "Upload failed. Could not get file info." : "上传失败。无法获取文件信息。",
    "Invalid directory." : "无效文件夹。",
    "Files" : "文件",
    "All files" : "全部文件",
    "File could not be found" : "文件未找到",
    "Home" : "家庭",
    "Close" : "关闭",
    "Favorites" : "收藏",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
    "Total file size {size1} exceeds upload limit {size2}" : "总文件大小 {size1} 超过上传限制 {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
    "Error uploading file \"{fileName}\": {message}" : "上传文件错误 \"{fileName}\": {message}",
    "Could not get result from server." : "不能从服务器得到结果",
    "Uploading..." : "上传中...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中。现在离开此页会导致上传动作被取消。",
    "Actions" : "动作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Delete" : "删除",
    "Disconnect storage" : "断开储存连接",
    "Unshare" : "取消共享",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "不能重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "在文件夹 \"{dir}\" 中已经存在 \"{targetName}\" 。请换一个名字试下。",
    "Could not rename \"{fileName}\"" : "不能重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "不能创建文件夹 \"{dir}\" ，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "No entries in this folder match '{filter}'" : "此文件夹中无项目匹配“{filter}”",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 文件夹"],
    "_%n file_::_%n files_" : ["%n个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "You don’t have permission to upload or create files here" : "您没有权限来上传湖州哦和创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配“{filter}”"],
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Local link" : "本地链接",
    "Folder" : "文件夹",
    "New folder" : "增加文件夹",
    "{newname} already exists" : "{newname} 已经存在",
    "Upload" : "上传",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "A new file or folder has been <strong>created</strong>" : "一个新的文件或文件夹已被<strong>创建</strong>",
    "A file or folder has been <strong>changed</strong>" : "一个文件或文件夹已被<strong>修改</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "针对<strong>已收藏文件</strong>的新建和修改发送有限的通知 <em>(仅流)</em>",
    "A file or folder has been <strong>deleted</strong>" : "一个文件或文件夹已被<strong>删除</strong>",
    "A file or folder has been <strong>restored</strong>" : "一个文件或文件夹已经被 <strong>恢复</strong>",
    "You created %1$s" : "您创建了%1$s",
    "%2$s created %1$s" : "%2$s 创建了 %1$s",
    "%1$s was created in a public folder" : "%1$s 被创建在公开文件夹中",
    "You changed %1$s" : "您修改了%1$s",
    "%2$s changed %1$s" : "%2$s 修改了 %1$s",
    "You deleted %1$s" : "您删除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 删除了 %1$s",
    "You restored %1$s" : "你恢复了 %1$s",
    "%2$s restored %1$s" : "%2$s 恢复了 %1$s",
    "Changed by %2$s" : "被 %2$s 更改",
    "Deleted by %2$s" : "被 %2$s 删除",
    "Restored by %2$s" : "被 %2$s 恢复",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有从这里进行编辑的权限",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传一些内容或者与设备同步!",
    "No entries found in this folder" : "此文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您正尝试上传的文件超过了此服务器可以上传的最大容量限制",
    "No favorites" : "无收藏",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt"
},
"nplurals=1; plural=0;");
